@@ -121,7 +121,8 @@ execute if score #{namespace}.major load.status matches {major} if score #{names
 
 		# Decoder check
 		name, url = value["name"], value["url"]
-		decoder_command: str = f'tellraw @a {{"text":"- [{name}]","color":"gold","clickEvent":{{"action":"open_url","value":"{url}"}}}}'
+		lib_version = ".".join(map(str, value["version"]))
+		decoder_command: str = f'tellraw @a {{"text":"- [{name} (v{lib_version}+)]","color":"gold","clickEvent":{{"action":"open_url","value":"{url}"}}}}'
 		decoder_checks += check_version(config, lib_ns, value, decoder_command)
 
 	# Write check_dependencies.mcfunction
